@@ -6,6 +6,8 @@ import sseclient
 from threading import Thread
 
 
+logging = logging.getLogger("event_consumer")
+
 
 class EventConsumer:
 
@@ -18,7 +20,7 @@ class EventConsumer:
         self.thread = None
 
     def start(self):
-        self.thread = Thread(target=self.__listen)
+        self.thread = Thread(target=self.__listen, daemon=True)
         self.thread.start()
 
     def __listen(self):
